searchData={"items":[{"type":"module","title":"Ueberauth.Strategy.SlackV2","doc":"Implements an ÜeberauthSlack strategy for authentication with Slack V2 OAuth API.\n\nWhen configuring the strategy in the Üeberauth providers, you can specify some defaults.\n\n* `uid_field` - The field to use as the UID field. This can be any populated field in the info struct. Default `:email`\n* `default_scope` - The scope to request by default from slack (permissions). Default \"users:read\"\n* `default_users_scope` - The scope to request by default from slack (permissions). Default \"users:read\"\n* `oauth2_module` - The OAuth2 module to use. Default Ueberauth.Strategy.SlackV2.OAuth\n\n```elixir\n\nconfig :ueberauth, Ueberauth,\n  providers: [\n    slack: { Ueberauth.Strategy.SlackV2, [uid_field: :nickname, default_scope: \"users:read,users:write\"] }\n  ]\n```","ref":"Ueberauth.Strategy.SlackV2.html"},{"type":"function","title":"Ueberauth.Strategy.SlackV2.default_options/0","doc":"","ref":"Ueberauth.Strategy.SlackV2.html#default_options/0"},{"type":"module","title":"Ueberauth.Strategy.SlackV2.OAuth","doc":"An implementation of OAuth2 for Slack OAuth V2 API.\nTo add your `client_id` and `client_secret` include these values in your configuration.\n    config :ueberauth, Ueberauth.Strategy.SlackV2.OAuth,\n      client_id: System.get_env(\"SLACK_CLIENT_ID\"),\n      client_secret: System.get_env(\"SLACK_CLIENT_SECRET\")\nThe JSON serializer used is the same as `Ueberauth` so if you need to\ncustomize it, you can configure it in the `Ueberauth` configuration:\n    config :ueberauth, Ueberauth,\n      json_library: Poison # Defaults to Jason","ref":"Ueberauth.Strategy.SlackV2.OAuth.html"},{"type":"function","title":"Ueberauth.Strategy.SlackV2.OAuth.authorize_url/2","doc":"","ref":"Ueberauth.Strategy.SlackV2.OAuth.html#authorize_url/2"},{"type":"function","title":"Ueberauth.Strategy.SlackV2.OAuth.authorize_url!/2","doc":"","ref":"Ueberauth.Strategy.SlackV2.OAuth.html#authorize_url!/2"},{"type":"function","title":"Ueberauth.Strategy.SlackV2.OAuth.client/1","doc":"","ref":"Ueberauth.Strategy.SlackV2.OAuth.html#client/1"},{"type":"function","title":"Ueberauth.Strategy.SlackV2.OAuth.get/5","doc":"","ref":"Ueberauth.Strategy.SlackV2.OAuth.html#get/5"},{"type":"function","title":"Ueberauth.Strategy.SlackV2.OAuth.get_token/3","doc":"","ref":"Ueberauth.Strategy.SlackV2.OAuth.html#get_token/3"},{"type":"function","title":"Ueberauth.Strategy.SlackV2.OAuth.get_token!/2","doc":"Returns two tokens from Slack API, a \"bot token\" and a \"user token\"","ref":"Ueberauth.Strategy.SlackV2.OAuth.html#get_token!/2"},{"type":"extras","title":"Überauth Slack V2","doc":"# Überauth Slack V2\n\n> Slack V2 OAuth2 strategy for Überauth.","ref":"README.html"},{"type":"extras","title":"Installation - Überauth Slack V2","doc":"1. Setup your application at [Slack API](https://api.slack.com).\n\n1. Add `:ueberauth_slack` to your list of dependencies in `mix.exs`:\n\n    ```elixir\n    def deps do\n      [{:ueberauth_slack_v2, \"~> 1.0\"}]\n    end\n    ```\n\n1. Add Slack to your Überauth configuration:\n\n    ```elixir\n    config :ueberauth, Ueberauth,\n      providers: [\n        slack: {Ueberauth.Strategy.SlackV2, []}\n      ]\n    ```\n\n    You can optionally restrict authentication by providing your team ID. [Find your Slack team ID here](https://api.slack.com/methods/auth.test/test). Note that this is NOT your team's Slack domain name!\n\n    ```elixir\n    config :ueberauth, Ueberauth,\n      providers: [\n        slack: {Ueberauth.Strategy.SlackV2, [team: \"0ABCDEF\"]}\n      ]\n    ```\n\n1.  Update your provider configuration:\n\n    ```elixir\n    config :ueberauth, Ueberauth.Strategy.SlackV2.OAuth,\n      client_id: System.get_env(\"SLACK_CLIENT_ID\"),\n      client_secret: System.get_env(\"SLACK_CLIENT_SECRET\")\n    ```\n\n1.  Include the Überauth plug in your controller:\n\n    ```elixir\n    defmodule MyApp.AuthController do\n      use MyApp.Web, :controller\n      plug Ueberauth\n      ...\n    end\n    ```\n\n1.  Create the request and callback routes if you haven't already:\n\n    ```elixir\n    scope \"/auth\", MyApp do\n      pipe_through :browser\n\n      get \"/:provider\", AuthController, :request\n      get \"/:provider/callback\", AuthController, :callback\n    end\n    ```\n\n1. Your controller needs to implement callbacks to deal with `Ueberauth.Auth` and `Ueberauth.Failure` responses.\n\nFor an example implementation see the [Überauth Example](https://github.com/ueberauth/ueberauth_example) application.","ref":"README.html#installation"},{"type":"extras","title":"Calling - Überauth Slack V2","doc":"Depending on the configured url you can initiate the request through:\n\n    /auth/slack\n\nOr with options:\n\n    /auth/slack?scope=users:read&user_scope=dnd:write\n\nBy default the requested scope is \"users:read\". Scope can be configured either explicitly as a `scope` query value on the request path or in your configuration:\n\n```elixir\nconfig :ueberauth, Ueberauth,\n  providers: [\n    slack: {Ueberauth.Strategy.SlackV2, [\n      default_scope: \"users:read,users:write\",\n      default_user_scope: \"dnd:write\"\n    ]}\n  ]\n```","ref":"README.html#calling"},{"type":"extras","title":"License - Überauth Slack V2","doc":"Please see [LICENSE](https://github.com/ueberauth/ueberauth_slack/blob/master/LICENSE) for licensing details.","ref":"README.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n\n## [2.0.0] - 2021-09-29","ref":"CHANGELOG.html"},{"type":"extras","title":"Added - Changelog","doc":"- Support CSRF requirement for Ueberauth >= 0.7.0\n\n## [1.1.1] - 2021-05-02","ref":"CHANGELOG.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Internal refactor\n\n## [1.1.0] - 2021-05-02","ref":"CHANGELOG.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Use `Authorization` header for API requests. Slack appears to have deprecated parameter-based requests.\n\n## [1.0.1] - 2021-02-21","ref":"CHANGELOG.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Support for Slack V2 OAuth API\n- Base code on original Ueberauth Slack project","ref":"CHANGELOG.html#added"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}